@@ -19,6 +19,8 @@ except Exception:
             # this always fails
             from ._prophet import ProphetWrapper
 
+    ProphetWrapper()
+
 
 try:
     from ._sarimax import SarimaxWrapper
@@ -33,11 +35,13 @@ except Exception:
             # this always fails
             from ._sarimax import SarimaxWrapper
 
+    SarimaxWrapper()
+
 
 try:
-    from ._smoothing import ExponentialSmoothingWrapper, SimpleSmoothingWrapper, HoltSmoothingWrapper
+    from ._smoothing import ExponentialSmoothingWrapper
 
-    __all__ += ["ExponentialSmoothingWrapper", "SimpleSmoothingWrapper", "HoltSmoothingWrapper"]
+    __all__ += ["ExponentialSmoothingWrapper"]
 except Exception:
 
     class ExponentialSmoothingWrapper:
@@ -47,6 +51,14 @@ except Exception:
             # this always fails
             from ._smoothing import ExponentialSmoothingWrapper
 
+    ExponentialSmoothingWrapper()
+
+try:
+    from ._smoothing import SimpleSmoothingWrapper
+
+    __all__ += ["SimpleSmoothingWrapper"]
+except Exception:
+
     class SimpleSmoothingWrapper:
         """This is just helper class to inform user about missing dependencies at init time"""
 
@@ -54,6 +66,14 @@ except Exception:
             # this always fails
             from ._smoothing import SimpleSmoothingWrapper
 
+    SimpleSmoothingWrapper()
+
+try:
+    from ._smoothing import HoltSmoothingWrapper
+
+    __all__ += ["HoltSmoothingWrapper"]
+except Exception:
+
     class HoltSmoothingWrapper:
         """This is just helper class to inform user about missing dependencies at init time"""
 
@@ -61,11 +81,13 @@ except Exception:
             # this always fails
             from ._smoothing import HoltSmoothingWrapper
 
+    HoltSmoothingWrapper()
+
 
 try:
-    from ._tbats import TBATSWrapper, BATSWrapper
+    from ._tbats import TBATSWrapper
 
-    __all__ += ["TBATSWrapper", "BATSWrapper"]
+    __all__ += ["TBATSWrapper"]
 except Exception:
 
     class TBATSWrapper:
@@ -75,9 +97,19 @@ except Exception:
             # this always fails
             from ._tbats import TBATSWrapper
 
+    TBATSWrapper()
+
+try:
+    from ._tbats import BATSWrapper
+
+    __all__ += ["BATSWrapper"]
+except Exception:
+
     class BATSWrapper:
         """This is just helper class to inform user about missing dependencies at init time"""
 
         def __init__(self):
             # this always fails
             from ._tbats import BATSWrapper
+
+    BATSWrapper()
