@@ -9,8 +9,7 @@ from hcrystalball.wrappers import (
 
 @pytest.mark.parametrize("X_y_optional", [("just_X"), ("")], indirect=["X_y_optional"])
 @pytest.mark.parametrize(
-    "model_type",
-    [ExponentialSmoothingWrapper, HoltSmoothingWrapper, SimpleSmoothingWrapper],
+    "model_type", [ExponentialSmoothingWrapper, HoltSmoothingWrapper, SimpleSmoothingWrapper],
 )
 def test_smoothing_transform_data_to_tsmodel_input_format(X_y_optional, model_type):
 
